@@ -3,7 +3,7 @@ from enum import Enum
 from typing import *
 
 if not os.getenv("READ_THE_DOCS"):
-    from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import Identifier, Partition, SearchSpec
+    from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import Identifier, Partition, SearchSpec, CoverageSpec
     from cognite.seismic.protos.v1.seismic_service_messages_pb2 import (
         CreatePartitionRequest,
         EditPartitionRequest,
@@ -64,3 +64,17 @@ def get_search_spec(
     if name_substring is not None:
         spec.name_substring = name_substring
     return spec
+
+
+def get_coverage_spec(crs: Optional[str], format: Optional[str]) -> CoverageSpec:
+    """Turns an optional crs and an optional string into a CoverageSpec.
+    """
+    if format == None:
+        format = "wkt"
+
+    if format == "wkt":
+        return CoverageSpec(crs=coverage_crs, format=0)
+    elif format == "geojson":
+        return CoverageSpec(crs=coverage_crs, format=1)
+    else:
+        raise ValueError(f"Unknown format {format}")
