@@ -13,6 +13,7 @@ if not os.getenv("READ_THE_DOCS"):
     from cognite.seismic.protos.types_pb2 import IngestionSource, Wkt
     from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import BinaryHeader as BinaryHeaderProto
     from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import TextHeader as TextHeaderProto
+    from google.protobuf.json_format import MessageToDict
 else:
     from enum import Enum
 
@@ -522,8 +523,7 @@ class Geometry:
         May return None if neither geojson nor wkt are specified.
         """
         crs = proto.crs.crs
-        # TODO: the json is a Struct, when it should probably be a python type.
-        geojson = proto.geo.json or None
+        geojson = MessageToDict(proto.geo.json) or None
         wkt = proto.wkt.geometry or None
         if geojson is None and wkt is None:
             return None
